%Hannu Pasanen
%9th of September 2019

%Determines the change in refractive index and 
%extinction coefficient (imaginary part) from transient reflectance and
%transmittance.
clear;
close all;
tic;
%% basic settings

%input the index for the delay time you wish to use for fitting
delay_time_index=108;

%input the thicknesses to be simulated. Each thickness is calculated and presented separately, and they replace the film_thickness from the simulation_settings.
thicknesses=linspace(450,500,20);

%resolution of the calculations. 1 calculates all the given data points.
resolution=1/2;

%% loads measured data (reflectance first, then transmittance)
    [filename, directory_name] = uigetfile('*.dat', 'Select a file');
    fullname = fullfile(directory_name, filename);
    data_dR0 = load(fullname);  
    
    data_wavelengths=data_dR0(2:end,1);
    
    data_dR=(data_dR0(2:end,delay_time_index)+data_dR0(2:end,delay_time_index-1)+data_dR0(2:end,delay_time_index+1))/3;
    data_dR=transpose(data_dR)*1000;
    
    [filename, directory_name] = uigetfile('*.dat', 'Select a file');
    fullname = fullfile(directory_name, filename);
    data_dT0 = load(fullname);   
    
    data_dT=(data_dT0(2:end,delay_time_index)+data_dT0(2:end,delay_time_index-1)+data_dT0(2:end,delay_time_index+1))/3;
    data_dT=transpose(data_dT)*1000;
    
    if resolution ~= 1
        wavelengths=linspace(data_wavelengths(1),data_wavelengths(end),round(length(data_wavelengths)*resolution));
        data_dR=interp1(data_wavelengths,data_dR,wavelengths);
        data_dT=interp1(data_wavelengths,data_dT,wavelengths);
    else
        wavelengths=data_wavelengths;
    end
    
    


%%

[film_thickness, film_layers, roughness_thickness, roughness_layers, ...
    diffusion_model_thickness, diffusion_model_points, ...
    absorbance, angle, ...
    n_air, n_film, n_glass, ...
    delta_n1,delta_n2, ...
    coating_thickness, n_coating,...
    substrate_coating_thickness,n_substrate_coating,...
    substrate_coating_film_roughness,scf_roughness_layers,...
    measurement_side, pol]=simulation_settings(wavelengths);

distribution=[1];

%{
x0 = linspace(0,length(distribution),length(distribution));
norm_factor=length(distribution)/sum(10.^(-absorbance*x0/length(distribution)));

distribution=10.^(-absorbance*x0/length(distribution))*norm_factor;
%}

toc;

for t=1:length(thicknesses)
tic;
%%
delta_n=ones(1,length(wavelengths)) *0.00001;
delta_n2=zeros(1,length(wavelengths));

for i=1:length(wavelengths)

        [~,~,dR_mOD_sim, dT_mOD_sim]=TRS_function_single_wavelength_lin_approx_thickness_variant(distribution,distribution,wavelengths(i),delta_n(i),delta_n2(i),thicknesses(t));
        
        Rn(i)=dR_mOD_sim/delta_n(i);
        Tn(i)=dT_mOD_sim/delta_n(i);
end

%%
delta_k=ones(1,length(wavelengths)) *1i*(0.00001);

for i=1:length(wavelengths)

        [~,~,dR_mOD_sim, dT_mOD_sim]=TRS_function_single_wavelength_lin_approx_thickness_variant(distribution,distribution,wavelengths(i),delta_k(i),delta_n2(i),thicknesses(t));
        
        Rk(i)=dR_mOD_sim/imag(delta_k(i));
        Tk(i)=dT_mOD_sim/imag(delta_k(i));
end

%%
        
lin_approx_dn=(data_dR.*Tk-data_dT.*Rk)./(Rn.*Tk-Tn.*Rk);
lin_approx_dk=(data_dT.*Rn-data_dR.*Tn)./(Rn.*Tk-Tn.*Rk);
        
dA_from_dk = 4*pi*lin_approx_dk./wavelengths ...
    *(film_thickness + roughness_thickness/3 +substrate_coating_film_roughness/3)/2.303;
       
    
    
    figure
    hold on
    plot(wavelengths,lin_approx_dn,'linewidth',2)
    plot(wavelengths,lin_approx_dk,'linewidth',2)
    line([wavelengths(1) wavelengths(end)], [0 0])
    axis([-Inf Inf -Inf Inf])
    set(gca, 'FontSize',14,'FontName','Arial');
    xlabel('wavelength (nm)','FontSize',20,'FontName','Arial'); 
    ylabel(['\Delta', 'n'],'FontSize',20,'FontName','Arial');
    title({['\Delta', 'n at ', num2str(data_dR0(1,delay_time_index)),'ps delay,',' thickness=',num2str(thicknesses(t))]},'Fontsize',20)
    legend({['\Delta', 'n'], ['\Delta', 'k']},'Fontsize',20,'Location','best')
    hold off
    
    disp(thicknesses(t))

lin_approx_dndk(:,1+(t-1)*4)=wavelengths;
lin_approx_dndk(:,2+(t-1)*4)=lin_approx_dn;
lin_approx_dndk(:,3+(t-1)*4)=lin_approx_dk;

toc;
end