close all; clear;


% loads measured reflectance data
%
[filename, directory_name] = uigetfile('*.txt', 'Select a file');
fullname = fullfile(directory_name, filename);
data_R = load(fullname);

% loads measured absorbance data
[filename, directory_name] = uigetfile('*.txt', 'Select a file');
fullname = fullfile(directory_name, filename);
data_A = load(fullname);
%}

%Wavelength vector [nm]
wavelengths = linspace(400,1500,700);

[film_thickness, film_layers, ...
    roughness_thickness, roughness_layers, ...
    ~, ~, ...
    ~, angle, ...
    n_air, n_film, n_glass,...
    ~, ~,...
    coating_thickness, n_coating,...
    substrate_coating_thickness,n_substrate_coating,...
    scf_roughness_thickness,scf_roughness_layers,...
    measurement_side, pol]=simulation_settings(wavelengths);

%% thicknesses of the roughness layers

if roughness_layers==0
    roughness_1=[];
else
    z = linspace(0,1,roughness_layers)*roughness_thickness;
    dz = roughness_thickness/(roughness_layers); %thickness of one roughness layer
    roughness_1=ones(1,roughness_layers)*dz;    
end

if scf_roughness_layers==0
    roughness_2=[];
else
z_2 = linspace(0,1,scf_roughness_layers)*scf_roughness_thickness;
dz_2=scf_roughness_thickness/scf_roughness_layers; %thickness of one roughness layer
roughness_2=ones(1,scf_roughness_layers)*dz_2;
end

%% thicknesses of all the layers
layers_thicknesses=[coating_thickness roughness_1 film_thickness roughness_2 substrate_coating_thickness];

%% roughness layer 1
if roughness_layers==0
    nf_roughness=[];
else    
        V=1/3 / roughness_thickness^2 * (z.^3 - (z-dz).^3); %volume of each roughness slice
        V_frac=V/dz;                                  %volume fraction of each roughness slice
        nf_roughness = sqrt(V_frac.*n_film.^2+(1-V_frac).*n_coating(:,length(n_coating(1,:))).^2);  %refractive index of roughness layer in steady state
end

%% roughness layer 2
if scf_roughness_layers==0
    nf_roughness_2=[];
else    
    V_2 = 1/3 / scf_roughness_thickness^2 * (z_2.^3 - (z_2-dz_2).^3); %volume of each roughness slice    
    V_frac_2 = V_2/dz_2;    
    nf_roughness_2 = sqrt( V_frac_2  .*n_film.^2 + (1- V_frac_2 ).*n_substrate_coating(:,1).^2); %refractive index of roughness layer in steady state
    nf_roughness_2=fliplr(nf_roughness_2);
    
end

%% refractive indexes
refractive_indexes=[n_coating nf_roughness n_film nf_roughness_2 n_substrate_coating];

%% simulates reflectance

for t=1:length(wavelengths)       
    
    %% Steady-state
    
    layers_n=refractive_indexes(t,:);
    
    [R0_with_substrate,T0_with_substrate]=transfer_matrix(n_air,n_glass(t),layers_n,layers_thicknesses,wavelengths(t),angle,'TM',measurement_side);  

    R_TM(t)=R0_with_substrate;
    T_TM(t)=T0_with_substrate;    
    
    [R0_with_substrate,T0_with_substrate]=transfer_matrix(n_air,n_glass(t),layers_n,layers_thicknesses,wavelengths(t),angle,'TE',measurement_side);  
    
    R_TE(t)=R0_with_substrate;
    T_TE(t)=T0_with_substrate; 
    
    
end

%%

R=(1-pol)*R_TM+pol*R_TE;
T=(1-pol)*T_TM+pol*T_TE;

figure
hold on
plot(wavelengths,100*R,'b','linewidth',2)
plot(wavelengths,100*T,'r','linewidth',2)
%
plot(data_R(:,1),data_R(:,2),'-g');
plot(data_A(:,1),100*10.^(-data_A(:,2))) %changes absorbance to transmittance
plot(data_R(:,1),data_R(:,2)+100*10.^(-data_A(:,2)))
%{
plot(data_A(:,1),data_A(:,2)*10);
plot(wavelengths,-10*log10(T),'-r','linewidth',2)
%}
axis([wavelengths(1) wavelengths(end) 0 Inf])
xlabel('Wavelength [nm]')
ylabel('R and T %')
legend 'Sim R' 'Sim T' 'Meas R' 'Meas T' 'Meas combined'
hold off


figure
hold on
plot(data_A(:,1),data_A(:,2),'c')
plot(wavelengths,-log10(T),'b--','linewidth',2)
plot(wavelengths,-log10(T)+log10(1-R),'r--','linewidth',2)
axis([wavelengths(1) wavelengths(end) 0 Inf])
xlabel('Wavelength [nm]')
ylabel('Absorption')
legend 'Meas A' 'Sim A+R' 'Sim A'
%legend 'Sim A+R' 'Sim A'
hold off

