%% Plots the simulated dR and dT at a single delay

clear;
close all;


[filename, directory_name] = uigetfile('*.dat', 'Select a file');
fullname = fullfile(directory_name, filename);
data_R = load(fullname); 
name_R=strrep(filename,'_',' ');
%}

%% settings

%wavelengths to plot
wavelengths=data_R(2:end,1);
%wavelengths=linspace(900,1100,200);

delay_time_index=100;

data_to_plot=(data_R(2:end,delay_time_index))*1000;
%data_to_plot=(data_R(2:end,delay_time_index)+data_R(2:end,delay_time_index+1)+data_R(2:end,delay_time_index-1))/3*1000;

[film_thickness, ~, ~, ~, ...
    ~, ~, ...
    A, ~, ...
    ~, ~, ~, ...
    delta_n1,delta_n2, ...
    ~, ~,...
    ~,~,...
    ~,~,...
    ~]=simulation_settings(wavelengths);

delta_n1=delta_n1.';

delta_n2=delta_n2.';

%% carrier distribution adjustment

distributions1=[1]; %uniform distribution

% non-uniform distribution
%{
x = linspace(0,film_thickness,film_thickness);
distributions1=10.^(-A*x/film_thickness);
distributions1=distributions1/sum(distributions1)*film_thickness;
%}

distributions2=distributions1;


%%

for i=1:length(wavelengths)
    [dR_sim, dT_sim]=TRS_function_single_wavelength(distributions1,distributions2,wavelengths(i),delta_n1(i),delta_n2(i));

    sim_R(i)=dR_sim;
    sim_T(i)=dT_sim;
end

figure
hold on
plot(wavelengths,sim_R,'Linewidth',2)
plot(wavelengths,sim_T,'Linewidth',2)
plot(wavelengths,data_to_plot,'Linewidth',2)
line([wavelengths(1) wavelengths(end)], [0 0])
hold off
axis([-Inf Inf -Inf Inf])
ylabel('mOD')
xlabel('wavelength, nm')
title(['\Delta', 'R and', '\Delta', 'T, thickness = ', num2str(film_thickness) ])
legend( {['sim. \Delta', 'R'],['sim. \Delta', 'T'],['meas. \Delta', 'R']},'Fontsize',14)
set(gca,'FontSize',14)