%Hannu Pasanen
%9th of September 2019

%Draws figures of transient reflectance and transmittance simulations and the distributions.
%The transmittance values are multiplied by 4 for clarity, 
%Saves the results of simulations as sim_R and sim_T.
%Asks for measurement data, provide transient reflectance data first 
%then transient transmittance data.
%Adjust wavelengths that you want plotted, diffusion constant, delay times
%and lifetime in settings below.

clear;
close all;
%% settings

%choose what to plot (1 plots, 0 doesn't)
plot_sim_dR=1;
plot_sim_scc=1;
plot_sim_dT=1;
plot_data_R=1;
plot_data_T=1;


%wavelengths to plot
wavelengths=[linspace(900,1060,10)];


%diffusion constant
D0=170; %constant
D1=0; %e^(-t/tau1)
tau1=1;
D2=0;    %e^(-t/tau2)
tau2=1;

%timepoints (in picoseconds) to simulate

delay_times=[0,0.1, 0.2, 0.4, 0.7,1,1.5,2,3,4,5,6,7,8,9,...%1-15
    10,15,20,30,40,50,75, ...%13-19
    100,200,300,400,500,600,700,800,900,...%20-28
    1000,2000,3000,4000,5000]; %29-33


%multiplier for transmittance to improve figure clarity (only affects
%figure drawing, not simulation)
transmittance_multiplier=1;

%adjusts measured data delay times
meas_delay_adjustment=0;

%%
[film_thickness, film_layers, roughness_thickness, roughness_layers, ...
    diffusion_model_thickness, diffusion_model_points, ...
    absorbance, angle, ...
    n_air, n_film, n_glass, ...
    delta_n1,delta_n2, ...
    coating_thickness, n_coating,...
    substrate_coating_thickness,n_substrate_coating,...
    substrate_coating_film_roughness,scf_roughness_layers,...
    measurement_side]=simulation_settings(wavelengths);

%% delta-n as function of time (by default the delta_n1 is constant)

%delta_n1
delta_n1=delta_n1.'; %transpose
%delta_n_modification=delta_n_modification(wavelengths).';

delta_n1=delta_n1*ones(1,length(delay_times));

%delta_n2
delta_n2=delta_n2.'; %transpose
delta_n2=delta_n2*ones(1,length(delay_times));

%% load measured data

%reflectance

if plot_data_R==1

[filename, directory_name] = uigetfile('*.dat', 'Select a file');
fullname_R = fullfile(directory_name, filename);

if size(fullname_R)==[1 3]
    plot_data_R=0;
end


if plot_data_R==1
    data_R = load(fullname_R); 
    name_R=strrep(filename,'_',' ');
end

end

%transmittance

if plot_data_T==1
    
[filename, directory_name] = uigetfile('*.dat', 'Select a file');
fullname_T = fullfile(directory_name, filename);

if size(fullname_T)==[1 3]
    plot_data_T=0;
end

if plot_data_T==1
    data_T = load(fullname_T); 
    name_T=strrep(filename,'_',' ');
end

end


%% distribution calculation
distributions1=diffusion_model_pdex11(D2,D1,D0,tau1,tau2,absorbance,diffusion_model_thickness,diffusion_model_points,delay_times);

disp('distributions calculated')
   
distributions2=distributions1;

scc=0;
for i=1:6
    scc=scc+distributions1(:,i);
end
scc=scc/6;

%% plots the distributions

x=linspace(0,diffusion_model_thickness,diffusion_model_points);    
figure
hold on
plot(x,distributions1(1,:)/distributions1(1,1),'color',[0.5 0 0],'linewidth',1.5);
plot(x,distributions1(3+3,:)/distributions1(1,1),'color',[1 0 0],'linewidth',1.5);
plot(x,distributions1(6+3,:)/distributions1(1,1),'color',[1 0 0.25],'linewidth',1.5);
plot(x,distributions1(10+3,:)/distributions1(1,1),'color',[1 0 0.5],'linewidth',1.5);
plot(x,distributions1(13+3,:)/distributions1(1,1),'color',[1 0 0.75],'linewidth',1.5);
plot(x,distributions1(16+3,:)/distributions1(1,1),'color',[1 0 1],'linewidth',1.5);
plot(x,distributions1(20+3,:)/distributions1(1,1),'color',[0.7 0 1],'linewidth',1.5);
plot(x,distributions1(22+3,:)/distributions1(1,1),'color',[0.4 0 1],'linewidth',1.5);
plot(x,distributions1(29+3,:)/distributions1(1,1),'color',[0 0 1],'linewidth',1.5);
plot(x,distributions1(30+3,:)/distributions1(1,1),'color',[0 0 0.5],'linewidth',1);
plot(x,distributions1(31+3,:)/distributions1(1,1),'color',[0 0 0.5],'linewidth',1);
plot(x,distributions1(32+3,:)/distributions1(1,1),'color',[0 0 0.5],'linewidth',1);
plot(x,distributions1(33+3,:)/distributions1(1,1),'color',[0 0 0.5],'linewidth',1);
xlabel('film (nm)','FontSize',20,'FontName','Arial'); 
ylabel('charge carriers (a.u.)','FontSize',20,'FontName','Arial');
axis([0 diffusion_model_thickness 0 1])
title({['Distributions',', A=', num2str(absorbance),', D=', num2str(D1)]},'Fontsize',20)
legend({'0 ps','1 ps', '3 ps','7 ps','10 ps', '30 ps','100 ps','300 ps','1000 ps'},'Fontsize',16)
legend boxoff
hold off


%% reflectance calculation

sim_R=zeros(length(wavelengths),length(distributions1(:,1)));
sim_T=zeros(length(wavelengths),length(distributions1(:,1)));

for i=1:length(wavelengths)

%finds the measured data closest to the given wavelengths 

if plot_data_R==1
M=abs(data_R(2:length(data_R(:,1)),1)-wavelengths(i));
[~,I]=min(M);
I=I(1);

wavelengths(i)=data_R(I+1,1);
end

if plot_data_T==1
M=abs(data_T(2:length(data_T(:,1)),1)-wavelengths(i));
[~,I]=min(M);
I=I(1);

wavelengths(i)=data_T(I+1,1);
end


%% dR and dT sim
[dR_sim, dT_sim]=TRS_function_single_wavelength(distributions1,distributions2,wavelengths(i),delta_n1(i,:),delta_n2(i,:));
  
%% figures

names={};

figure
hold on
if plot_sim_dR==1
    semilogx(delay_times,dR_sim,'c','linewidth',2)
    names(1)={['sim. ','\Delta','R']};
end
if plot_sim_scc==1
    semilogx(delay_times, scc/scc(end)*dR_sim(end),'g','linewidth',2)
    names(1+plot_sim_dR)={'sim. scc'};
end
if plot_data_R==1
    semilogx(data_R(1, 2:length(data_R(1,:)))+meas_delay_adjustment, data_R(I, 2:length(data_R(1,:)))*1000,'b','linewidth',2)
    names(1+plot_sim_dR+plot_sim_scc)={['meas. ','\Delta','R']};
end
if plot_sim_dT==1
    semilogx(delay_times,dT_sim*transmittance_multiplier,'m','linewidth',2)
    names(1+plot_sim_dR+plot_sim_scc+plot_data_R)={['sim. ','\Delta','T']};
end
if plot_data_T==1
    semilogx(data_T(1, 2:length(data_T(1,:))),data_T(I, 2:length(data_T(1,:)))*1000*transmittance_multiplier,'r','linewidth',2)
    names(1+plot_sim_dR+plot_sim_scc+plot_data_R+plot_sim_dT)={['meas. ','\Delta','T']};
end
line([0.1 5400], [0 0])
set(gca, 'XScale', 'log');
set(gca, 'FontSize',12,'FontName','Arial');
axis([0.1 3000 -Inf Inf])
   
xlabel('time (ps)','FontSize',20,'FontName','Arial'); 
xticks=([1 10 100 1000]);
%ylabel(['\Delta', 'R ','and \Delta', 'T ','(mOD)'],'FontSize',20,'FontName','Arial');
ylabel(['\Delta', 'R (mOD)'],'FontSize',20,'FontName','Arial');
%title({['Evolution of signal at ', num2str(wavelengths(i)),'nm',', A=', num2str(absorbance),', D=', num2str(D1)]},'Fontsize',20)
title({[num2str(round(wavelengths(i))),'nm, ',' D=', num2str(D0),'+',num2str(D1),'e^{t/',num2str(tau1),'}+',num2str(D2),'e^{t/',num2str(tau2),'}']},'Fontsize',20)
legend(names,'Fontsize',20)
legend boxoff
%legend({['sim. ','\Delta','R'],['sim. scc'],['meas. ','\Delta','R'], ['sim. ','\Delta','T'],['meas. ','\Delta','T']},'Fontsize',20)

disp(['wavelength ', num2str(wavelengths(i)), ' done'])

%%

sim_R(i,:)=dR_sim;
sim_T(i,:)=dT_sim;

end

if plot_sim_dR==1

figure
hold on
delta_R_plots=plot(wavelengths, sim_R);
line([wavelengths(1) wavelengths(length(wavelengths))], [0 0])
axis([wavelengths(1) wavelengths(length(wavelengths)) -Inf Inf])
set(delta_R_plots(1), 'linewidth',3, 'color',[1 0 0])
set(delta_R_plots(length(delta_R_plots)), 'linewidth',3, 'color',[0 0 1])
set(gca,'FontSize',20)
xlabel('wavelength, nm','FontSize',22,'FontName','Arial'); 
ylabel(['\Delta', 'R, mOD'],'FontSize',22,'FontName','Arial');
title('simulated TR spectra','Fontsize',20)
hold off

end


if plot_sim_dT==1

figure
hold on
delta_T_plots=plot(wavelengths, sim_T);
line([wavelengths(1) wavelengths(length(wavelengths))], [0 0])
axis([wavelengths(1) wavelengths(length(wavelengths)) -Inf Inf])
set(delta_T_plots(1), 'linewidth',3, 'color',[1 0 0])
set(delta_T_plots(length(delta_T_plots)), 'linewidth',3, 'color',[0 0 1])
set(gca,'FontSize',24)
xlabel('wavelength, nm','FontSize',26,'FontName','Arial'); 
ylabel(['\Delta', 'T, mOD'],'FontSize',26,'FontName','Arial');
title('simulated TA spectra','Fontsize',26)
hold off

end


%%

if plot_data_R==1

delay_times=[1,10,100,500,5000];
 clear actual_delay_times; clear delay_times_str;
 clear plot_minima; clear plot_maxima;
 
delay_time_index=zeros(1,length(delay_times),1);
actual_delay_times=zeros(1,length(delay_times),1);

for i=1:length(delay_times)
    M=abs(data_R(1,2:length(data_R(1,:)))-delay_times(i));
    [~,I]=min(M);
    delay_time_index(i)=I(1)+1;
    actual_delay_times(i)=data_R(1,I(1)+1); 
    delay_times_str{i}=strcat(num2str(actual_delay_times(i)),' ps');
end

[~,w_min_index]=min(abs(data_R(:,1)-wavelengths(1)));
[~,w_max_index]=min(abs(data_R(:,1)-wavelengths(end)));

color=linspace(0,1,length(delay_times));

figure
hold on
for i=1:length(delay_times)
    plot(data_R(w_min_index:w_max_index,1),data_R(w_min_index:w_max_index,delay_time_index(i))*1000,'color',[0 0 1-color(i)],'linewidth',1.5)
end
line([data_R(w_min_index,1) data_R(w_max_index,1)], [0 0])
axis([wavelengths(1) wavelengths(end) -Inf Inf])
xlabel('wavelength (nm)','FontSize',20,'FontName','Arial'); 
title(name_R,'FontSize',20,'FontName','Arial'); 
ylabel(['\Delta', 'R ','(mOD)'],'FontSize',20,'FontName','Arial');
set(gca,'FontSize',20)
%ylabel(['mOD'],'FontSize',20,'FontName','Arial');
legend(delay_times_str,'Fontsize',20)
legend('Location','best')
hold off

end

%%

if plot_data_T==1

delay_times=[1,10,100,500,5000];
 clear actual_delay_times; clear delay_times_str;
 clear plot_minima; clear plot_maxima;
 
 delay_time_index=zeros(1,length(delay_times));
actual_delay_times=zeros(1,length(delay_times));

for i=1:length(delay_times)
    M=abs(data_T(1,2:length(data_T(1,:)))-delay_times(i));
    [~,I]=min(M);
    delay_time_index(i)=I(1)+1;
    actual_delay_times(i)=data_T(1,I(1)+1); 
    delay_times_str{i}=strcat(num2str(actual_delay_times(i)),' ps');
end

[~,w_min_index]=min(abs(data_T(:,1)-wavelengths(1)));
[~,w_max_index]=min(abs(data_T(:,1)-wavelengths(end)));
a=length(data_T(:,1));

color=linspace(0,1,length(delay_times));

figure
hold on
for i=1:length(delay_times)
    plot(data_T(w_min_index:w_max_index,1),data_T(w_min_index:w_max_index,delay_time_index(i))*1000,'color',[1-color(i) 0 0],'linewidth',1.5)
end
line([wavelengths(1) wavelengths(end)], [0 0])
axis([-Inf Inf -Inf Inf])
xlabel('wavelength (nm)','FontSize',20,'FontName','Arial'); 
title(name_T,'FontSize',20,'FontName','Arial'); 
ylabel(['\Delta', 'T ','(mOD)'],'FontSize',20,'FontName','Arial');
set(gca,'FontSize',20)
%ylabel(['mOD'],'FontSize',20,'FontName','Arial');
legend(delay_times_str,'Fontsize',20)
legend('Location','best')
hold off
%}

end

