%Hannu Pasanen
%16th of September 2019

function [dR_sim, dT_sim] = TRS_function_single_wavelength(distributions1,distributions2,wavelength,delta_n1,delta_n2)

[film_thickness, film_layers, roughness_thickness, roughness_layers, ...
    ~, ~, ...
    ~, angle, ...
    n_air, n_film, n_glass, ...
    ~,~, ...
    coating_thickness, n_coating,...
    substrate_coating_thickness,n_substrate_coating,...
    scf_roughness_thickness,scf_roughness_layers,...
    measurement_side, pol]=simulation_settings(wavelength);


%% thicknesses of the roughness layers

if roughness_layers==0
    roughness_1=[];
else
    z = linspace(0,1,roughness_layers)*roughness_thickness;
    dz = roughness_thickness/(roughness_layers); %thickness of one roughness layer
    roughness_1=ones(1,roughness_layers)*dz;    
end

if scf_roughness_layers==0
    roughness_2=[];
else
z_2 = linspace(0,1,scf_roughness_layers)*scf_roughness_thickness;
dz_2=scf_roughness_thickness/scf_roughness_layers; %thickness of one roughness layer
roughness_2=ones(1,scf_roughness_layers)*dz_2;
end

film_thickness=ones(1,film_layers)*film_thickness/film_layers;

%thicknesses of all the layers
layers_thicknesses_total=[coating_thickness roughness_1 film_thickness roughness_2 substrate_coating_thickness];






%% roughness layer 1
if roughness_layers==0
    nf_roughness=[];
    V_frac_1=[];
    V=[];
else    
        V=1/3 / roughness_thickness^2 * (z.^3 - (z-dz).^3); %volume of each roughness slice
        V_frac_1=V/dz;                                  %volume fraction of each roughness slice
        nf_roughness = sqrt(V_frac_1.*n_film.^2+(1-V_frac_1).*n_coating(end).^2);  %refractive index of roughness layer in steady state
        %length(n_coating(1,:))
end
%%

for Z = 1:roughness_layers %roughness layer 1
    thickness_point(Z)=sum(V(1:Z));
end


if roughness_layers==0
    thickness_point(1)=film_thickness(1);
    
    for Z = 2:film_layers
        thickness_point(Z)=thickness_point(Z-1)+film_thickness(Z);
        %V_frac_total(Z)=1;
    end
    
else
for Z = (1+roughness_layers):(film_layers+roughness_layers) % bulk film
    
    %total volume of perovskite as function of depth
    thickness_point(Z)=thickness_point(Z-1)+film_thickness(Z-roughness_layers);  
    
    %volume fraction of a bulk layer
    %V_frac_total(Z)=1;
    
    
end
end

%% roughness layer 2
if scf_roughness_layers==0
    nf_roughness_2=[];
    V_frac_2=[];
    V_2=[];
else    
    V_2 =fliplr( 1/3 / scf_roughness_thickness^2 * (z_2.^3 - (z_2-dz_2).^3)); %volume of each roughness slice    
    V_frac_2 = V_2/dz_2;    
    nf_roughness_2 = sqrt( V_frac_2  .*n_film.^2 + (1- V_frac_2 ).*n_substrate_coating(1).^2); %refractive index of roughness layer in steady state
        
end

V_frac_total = [V_frac_1 ones(1,film_layers) V_frac_2];

%%

for Z = (1+roughness_layers+film_layers):(film_layers+roughness_layers+scf_roughness_layers)
    thickness_point(Z)=thickness_point(Z-1)+V_2(Z-roughness_layers-film_layers);
end

%% bottom-side adjustment
if strcmp(measurement_side,'bottom')
    thickness_point=0;
    V=fliplr(V);
    V_2=fliplr(V_2);
    V_frac_total=fliplr(V_frac_total);
    
    if scf_roughness_layers==0
        thickness_point(1)=film_thickness(1);
        for Z = 2:film_layers
            thickness_point(Z)=thickness_point(Z-1)+film_thickness(Z);
        end
        
        if roughness_layers==0
        else
            for Z = (1+scf_roughness_layers+film_layers):(film_layers+roughness_layers+scf_roughness_layers)
                thickness_point(Z)=thickness_point(Z-1)+V(Z-scf_roughness_layers-film_layers);
            end
        end
    else
    for Z = 1:scf_roughness_layers %roughness layer 1
    thickness_point(Z)=sum(V_2(1:Z));
    end
    
    
    for Z = (1+scf_roughness_layers):(film_layers+scf_roughness_layers) % bulk film
    
    %total volume of perovskite as function of depth
    thickness_point(Z)=thickness_point(Z-1)+film_thickness(Z-scf_roughness_layers); 
    
    end
    
    for Z = (1+scf_roughness_layers+film_layers):(film_layers+roughness_layers+scf_roughness_layers)
    thickness_point(Z)=thickness_point(Z-1)+V(Z-scf_roughness_layers-film_layers);
    end
    end
end

%%

% combines roughness and bulk layers
n_total=[n_coating...
    nf_roughness...
    ones(1,film_layers)*n_film ...
    nf_roughness_2...
    n_substrate_coating];


%%
polarization='TM';

%% Steady-state 
[R0_with_substrate,T0_with_substrate]=transfer_matrix(n_air,n_glass,n_total,layers_thicknesses_total,wavelength,angle,polarization,measurement_side);
     
dR_sim_TM=ones(1,length(distributions1(:,1)));
dT_sim_TM=ones(1,length(distributions1(:,1)));    
    %% charge diffusion after excitation
        a=length(distributions1(1,:));
        if strcmp(measurement_side,'top')
    for m=1:length(distributions1(:,1))       %measurements from top side
        
        %estimates amount of charge carriers in each layer and calculates
        %new refractive index for each layer
        n=ones(1,film_layers+roughness_layers+scf_roughness_layers);
        for i=1:(film_layers+roughness_layers+scf_roughness_layers) 
            temp=round(a * thickness_point(i)/thickness_point(end));  
            if temp>length(distributions1(m,:))
                temp=length(distributions1(m,:));
            elseif temp==0
                temp=1;
            end
            new_n=n_film+delta_n1(m)*distributions1(m,temp)+delta_n2(m)*distributions2(m,temp);            
            
            if i<=roughness_layers
                n(i)=sqrt(V_frac_total(i)*new_n.^2+(1-V_frac_total(i))*n_coating(end).^2);
            elseif i>film_layers+roughness_layers
                n(i)=sqrt(V_frac_total(i)*new_n.^2+(1-V_frac_total(i))*n_substrate_coating(1).^2);
            else
                n(i)=new_n;
            end
            
        end
            
        n_total_new=[n_coating n n_substrate_coating];
        
        [R_sim_with_substrate,T_sim_with_substrate]=transfer_matrix(n_air,n_glass,n_total_new,layers_thicknesses_total,wavelength,angle,polarization,measurement_side);
          
        dR_sim_TM(m)=R_sim_with_substrate/R0_with_substrate*100 -100;
        dT_sim_TM(m)=T_sim_with_substrate/T0_with_substrate*100 -100;
        
    end  
        end
    
        if strcmp(measurement_side,'bottom')  
            
            for m=1:length(distributions1(:,1))       %measurements from bottom side
        
        %estimates amount of charge carriers in each layer and calculates
        %new refractive index for each layer
        for i=1:(film_layers+roughness_layers+scf_roughness_layers) 
            temp=round(a * thickness_point(i)/thickness_point(end));  
            if temp>length(distributions1(m,:))
                temp=length(distributions1(m,:));
            elseif temp==0
                temp=1;
            end
            new_n=n_film+delta_n1(m)*distributions1(m,temp)+delta_n2(m)*distributions2(m,temp);            
            
            if i<=scf_roughness_layers
                n(i)=sqrt(V_frac_total(i)*new_n.^2+(1-V_frac_total(i))*n_substrate_coating(1).^2);
            elseif i>film_layers+scf_roughness_layers
                n(i)=sqrt(V_frac_total(i)*new_n.^2+(1-V_frac_total(i))*n_coating(end).^2);
            else
                n(i)=new_n;
            end
            
        end
            
        n_total_new=[n_coating fliplr(n) n_substrate_coating];
             
        [R_sim_with_substrate,T_sim_with_substrate]=transfer_matrix(n_air,n_glass,n_total_new,layers_thicknesses_total,wavelength,angle,polarization,measurement_side);
          
        dR_sim_TM(m)=R_sim_with_substrate/R0_with_substrate*100 -100;
        dT_sim_TM(m)=T_sim_with_substrate/T0_with_substrate*100 -100;
        
            end
        end
            
%%
polarization='TE';

%% Steady-state 
[R0_with_substrate,T0_with_substrate]=transfer_matrix(n_air,n_glass,n_total,layers_thicknesses_total,wavelength,angle,polarization,measurement_side);
     
     
dR_sim_TE=ones(1,length(distributions1(:,1)));
dT_sim_TE=ones(1,length(distributions1(:,1)));        
    %% charge diffusion after excitation
        a=length(distributions1(1,:));
        if strcmp(measurement_side,'top')
    for m=1:length(distributions1(:,1))    
        
        for i=1:(film_layers+roughness_layers+scf_roughness_layers) 
            temp=round(a * thickness_point(i)/thickness_point(end));  
            if temp>length(distributions1(m,:))
                temp=length(distributions1(m,:));
            elseif temp==0
                temp=1;
            end
            new_n=n_film+delta_n1(m)*distributions1(m,temp)+delta_n2(m)*distributions2(m,temp);            
            
            if i<=roughness_layers
                n(i)=sqrt(V_frac_total(i)*new_n.^2+(1-V_frac_total(i))*n_coating(end).^2);
            elseif i>film_layers+roughness_layers
                n(i)=sqrt(V_frac_total(i)*new_n.^2+(1-V_frac_total(i))*n_substrate_coating(1).^2);
            else
                n(i)=new_n;
            end
            
        end
        
        n_total_new=[n_coating n n_substrate_coating];
        
        [R_sim_with_substrate,T_sim_with_substrate]=transfer_matrix(n_air,n_glass,n_total_new,layers_thicknesses_total,wavelength,angle,polarization,measurement_side);
          
        dR_sim_TE(m)=R_sim_with_substrate/R0_with_substrate*100 -100;
        dT_sim_TE(m)=T_sim_with_substrate/T0_with_substrate*100 -100;
        
    end
        end
    
    if strcmp(measurement_side,'bottom')  
            
            for m=1:length(distributions1(:,1))       %measurements from bottom side
        
        %estimates amount of charge carriers in each layer and calculates
        %new refractive index for each layer
        for i=1:(film_layers+roughness_layers+scf_roughness_layers) 
            temp=round(a * thickness_point(i)/thickness_point(end));  
            if temp>length(distributions1(m,:))
                temp=length(distributions1(m,:));
            elseif temp==0
                temp=1;
            end
            new_n=n_film+delta_n1(m)*distributions1(m,temp)+delta_n2(m)*distributions2(m,temp);            
            
            if i<=scf_roughness_layers
                n(i)=sqrt(V_frac_total(i)*new_n.^2+(1-V_frac_total(i))*n_substrate_coating(1).^2);
            elseif i>film_layers+scf_roughness_layers
                n(i)=sqrt(V_frac_total(i)*new_n.^2+(1-V_frac_total(i))*n_coating(end).^2);
            else
                n(i)=new_n;
            end
            
        end
        
            
        n_total_new=[n_coating fliplr(n) n_substrate_coating];
    
             
        [R_sim_with_substrate,T_sim_with_substrate]=transfer_matrix(n_air,n_glass,n_total_new,layers_thicknesses_total,wavelength,angle,polarization,measurement_side);
          
        dR_sim_TE(m)=R_sim_with_substrate/R0_with_substrate*100 -100;
        dT_sim_TE(m)=T_sim_with_substrate/T0_with_substrate*100 -100;
        
            end        
    end

%% average of TE and TM, change to mOD units

%dR_sim=-log10(((dR_sim_TM+dR_sim_TE)/2)/100+1)*1000;
%dT_sim=-log10(((dT_sim_TM+dT_sim_TE)/2)/100+1)*1000;

dR_sim=-log10((pol*dR_sim_TE+(1-pol)*dR_sim_TM)/100+1)*1000;
dT_sim=-log10((pol*dT_sim_TE+(1-pol)*dT_sim_TM)/100+1)*1000;

end