function [film_thickness, film_layers, roughness_thickness, roughness_layers, ...
    diffusion_model_thickness, diffusion_model_points, ...
    A, angle, ...
    n_air, n_film, n_glass, ...
    delta_n1,delta_n2, ...
    coating_thickness, n_coating,...
    substrate_coating_thickness,n_substrate_coating,...
    scf_roughness,scf_roughness_layers,...
    measurement_side, polarization]=simulation_settings(wavelengths)
%%
%absorbance of sample at the pump wavelength
A=3;

%angle of measurements (angle of probe beam to sample surface from perpendicular in degrees)
angle=10; 

measurement_side='top'; %top (film) or bottom (through the substrate)

% polarization: xTE+(1-x)TM,  in other words 1=TE, 0=TM and 0.5=non-polarized

polarization=1;

%% Film properties

%thin film thickness
film_thickness=480;
%514;

%number of layers the film is split into
%film_layers=round(film_thickness);
film_layers=480;

%complex refractive index
n_film=n_perovskite_FAMACs(wavelengths/1000).';

%Photoinduced change in the complex refractive index (includes delta_k)
%Note that the diffusion simulation normalizes the dn so that the carrier concentration is 1 when the distribution is uniform across the entire film.
%Therefore the total amount of carriers is the same regardless of the initial distribution (absorbance),
%and the carrier amount is adjusted by multiplying/dividing the delta_n.
%Increasing the thickness of the film causes the normalization to also increase the delta_n to maintain uniform carrier concentration of 1.
%Finally, the program may bug if a negative dk is stronger than the
%steady-state k, pushing the overall k of the excited state to negative.
%This should be kept in mind especially when modelling high absorbance.
delta_n=delta_n_pero_NIR(wavelengths);
%delta_n=ones(1,length(wavelengths))*(-0.0001+1i*0.0001);

%carrier type 1
delta_n1=delta_n;

%carrier type 2
%by default the carrier type 2 has the same distribution as the carrier type 1
%set delta_n2=zeros(length(wavelengths),1).'; to have no second carrier type
delta_n2=zeros(length(wavelengths),1).';

%% Coating: The modelled sample structure is air - coating1 - coating2 - ... - film roughness - film - scf_roughness - substrate_coating1 - substrate_coating2 - ... -n_glass

%refractive index of air
n_air=1;

%coating thickness: [coating1 coating 2 coating 3...]
coating_thickness=[0];
%coating_thickness=[50 50];

%roughness at coating-film interface
%Thickness of roughness in nm; this affects the total thickness of the film.
%The roughness is calculated as nanocones with refractive index of the film surrounded by the coating. 
%If there is no coating, use n_coating=ones(length(wavelengths),1);
%If multiple coatings, the last one is used for the roughness calculation.
roughness_thickness=90;

%number of layers the roughness is split into
roughness_layers =90;


%Coating refractive index, ones(length(wavelengths),1) if no coating
%Multiple coatings with different refractive indexes:
%n_coating(:,1)=coating1(wavelengths/1000).'; n_coating(:,2)=coating2(wavelengths/1000).'; etc.
%The number of coating refractive indexes has to match the number of coating thicknesses!
%The refractive index given here will be used in the roughness simulation even if the coating_thickness is 0.
n_coating=ones(length(wavelengths),1);
%n_coating(:,1)=ones(length(wavelengths),1);
%n_coating(:,2)=n_GaInP(wavelengths/1000).';


%% same at film-substrate interface

substrate_coating_thickness=[0];

%The roughness between the film and the 1st substrate_coating
scf_roughness=0;

scf_roughness_layers=0;

%Complex refractive index of substrate
n_glass=n_soda_lime_glass(wavelengths/1000).';


n_substrate_coating(:,1)=n_film;
%n_GaInP(wavelengths/1000).';



%%
%thickness of diffusion model (should equal average film thickness; film_thickness + roughness_thickness/3)
diffusion_model_thickness=film_thickness;
if roughness_layers ~= 0
    diffusion_model_thickness=diffusion_model_thickness+roughness_thickness/3;
end
if scf_roughness_layers ~= 0
    diffusion_model_thickness=diffusion_model_thickness+scf_roughness/3;
end

%resolution of diffusion simulation
diffusion_model_points=round(diffusion_model_thickness); 


